@@ -486,78 +486,6 @@ struct heif_image *createImage_RGBA_interleaved()
   return image;
 }
 
-
-struct heif_image *createImage_RGB_planar()
-{
-  struct heif_image *image;
-  struct heif_error err;
-  int w = 1024;
-  int h = 768;
-  err = heif_image_create(w, h, heif_colorspace_RGB,
-                          heif_chroma_444, &image);
-  if (err.code) {
-    return nullptr;
-  }
-
-  err = heif_image_add_plane(image, heif_channel_R, w, h, 8);
-  REQUIRE(err.code == heif_error_Ok);
-  err = heif_image_add_plane(image, heif_channel_G, w, h, 8);
-  REQUIRE(err.code == heif_error_Ok);
-  err = heif_image_add_plane(image, heif_channel_B, w, h, 8);
-  REQUIRE(err.code == heif_error_Ok);
-
-
-  int stride;
-  uint8_t *r = heif_image_get_plane(image, heif_channel_R, &stride);
-  uint8_t *g = heif_image_get_plane(image, heif_channel_G, &stride);
-  uint8_t *b = heif_image_get_plane(image, heif_channel_B, &stride);
-
-  int y = 0;
-  for (; y < h / 2; y++) {
-    int x = 0;
-    for (; x < w / 3; x++) {
-      r[y * stride + x] = 1;
-      g[y * stride + x] = 255;
-      b[y * stride + x] = 2;
-    }
-    for (; x < 2 * w / 3; x++) {
-      r[y * stride + x] = 4;
-      g[y * stride + x] = 5;
-      b[y * stride + x] = 255;
-    }
-    for (; x < w; x++) {
-      r[y * stride + x] = 255;
-      g[y * stride + x] = 6;
-      b[y * stride + x] = 7;
-    }
-  }
-  for (; y < h; y++) {
-    int x = 0;
-    for (; x < w / 3; x++) {
-      r[y * stride + x]= 8;
-      g[y * stride + x] = 9;
-      b[y * stride + x] = 255;
-    }
-    for (; x < 2 * w / 3; x++) {
-      r[y * stride + x] = 253;
-      g[y * stride + x] = 10;
-      b[y * stride + x] = 11;
-    }
-    for (; x < w; x++) {
-      r[y * stride + x] = 13;
-      g[y * stride + x] = 252;
-      b[y * stride + x] = 12;
-    }
-  }
-  if (err.code) {
-    heif_image_release(image);
-    return nullptr;
-  }
-
-  return image;
-}
-
-
 struct heif_image *createImage_RGBA_planar()
 {
   struct heif_image *image;
@@ -637,7 +565,7 @@ struct heif_image *createImage_RGBA_planar()
   return image;
 }
 
-static void do_encode(heif_image* input_image, const char* filename, bool check_decode)
+static void do_encode(heif_image* input_image, const char* filename, bool check_decode, uint8_t prefer_uncC_short_form = 0)
 {
   REQUIRE(input_image != nullptr);
 
@@ -652,6 +580,7 @@ static void do_encode(heif_image* input_image, const char* filename, bool check_
   options->macOS_compatibility_workaround = false;
   options->macOS_compatibility_workaround_no_nclx_profile = true;
   options->image_orientation = heif_orientation_normal;
+  options->prefer_uncC_short_form = prefer_uncC_short_form;
   heif_image_handle *output_image_handle;
 
   err = heif_context_encode_image(ctx, input_image, encoder, options, &output_image_handle);
@@ -690,6 +619,7 @@ static void do_encode(heif_image* input_image, const char* filename, bool check_
     // TODO: make proper test for interleave to component translation
 
     // TODO: compare values
+    heif_image_release(decode_image);
     heif_image_handle_release(decode_image_handle);
     heif_context_free(decode_context);
   }
@@ -715,6 +645,11 @@ TEST_CASE("Encode Mono")
   do_encode(input_image, "encode_mono.heif", true);
 }
 
+TEST_CASE("Encode RGB Version1")
+{
+  heif_image *input_image = createImage_RGB_interleaved();
+  do_encode(input_image, "encode_rgb_version1.heif", true, true);
+}
 
 TEST_CASE("Encode Mono with alpha")
 {
@@ -779,6 +714,12 @@ TEST_CASE("Encode RGBA")
   do_encode(input_image, "encode_rgba.heif", true);
 }
 
+TEST_CASE("Encode RGBA Version 1")
+{
+  heif_image *input_image = createImage_RGBA_interleaved();
+  do_encode(input_image, "encode_rgba_version1.heif", true, true);
+}
+
 
 TEST_CASE("Encode RRRGGBBAA_LE 10 bit")
 {
